@@ -588,7 +588,7 @@ GPid
 meta_show_dialog (const char *type,
                   const char *message,
                   const char *timeout,
-                  const gint screen_number,
+                  const char *display,
                   const char *ok_text,
                   const char *cancel_text,
                   const int transient_for,
@@ -596,7 +596,6 @@ meta_show_dialog (const char *type,
                   GSList *entries)
 {
   GError *error = NULL;
-  char *screen_number_text = g_strdup_printf("%d", screen_number);
   GSList *tmp;
   int i=0;
   GPid child_pid;
@@ -607,8 +606,8 @@ meta_show_dialog (const char *type,
 
   argvl[i++] = "zenity";
   argvl[i++] = type;
-  argvl[i++] = "--screen";
-  argvl[i++] = screen_number_text;
+  argvl[i++] = "--display";
+  argvl[i++] = display;
   argvl[i++] = "--class";
   argvl[i++] = "mutter-dialog";
   argvl[i++] = "--title";
@@ -673,7 +672,6 @@ meta_show_dialog (const char *type,
     unsetenv ("WINDOWID");
 
   g_free (argvl);
-  g_free (screen_number_text);
 
   if (error)
     {
