@@ -22,10 +22,10 @@
  */
 
 #include <config.h>
-#include "util.h"
-#include "theme.h"
-#include "theme-parser.h"
-#include "preview-widget.h"
+#include <meta/util.h>
+#include <meta/theme.h>
+#include "theme-private.h"
+#include <meta/preview-widget.h>
 #include <gtk/gtk.h>
 #include <time.h>
 #include <stdlib.h>
@@ -35,8 +35,6 @@
 #define _(x) dgettext (GETTEXT_PACKAGE, x)
 #define N_(x) x
 
-#include "gdk2-drawing-utils.h"
-
 /* We need to compute all different button arrangements
  * in terms of button location. We don't care about
  * different arrangements in terms of button function.
@@ -237,7 +235,7 @@ dialog_contents (void)
   
   vbox = gtk_vbox_new (FALSE, 0);
 
-  action_area = gtk_hbutton_box_new ();
+  action_area = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
 
   gtk_button_box_set_layout (GTK_BUTTON_BOX (action_area),
                              GTK_BUTTONBOX_END);  
@@ -410,6 +408,10 @@ get_window_contents (MetaFrameType  type,
     case META_FRAME_TYPE_BORDER:
       *title = _("Border");
       return border_only_contents ();
+
+    case META_FRAME_TYPE_ATTACHED:
+      *title = _("Attached Modal Dialog");
+      return dialog_contents ();
       
     case META_FRAME_TYPE_LAST:
       g_assert_not_reached ();
@@ -457,6 +459,9 @@ get_window_flags (MetaFrameType type)
 
     case META_FRAME_TYPE_BORDER:
       break;
+
+    case META_FRAME_TYPE_ATTACHED:
+      break;
       
     case META_FRAME_TYPE_LAST:
       g_assert_not_reached ();
@@ -468,7 +473,7 @@ get_window_flags (MetaFrameType type)
 
 static GtkWidget*
 preview_collection (int font_size,
-                    PangoFontDescription *base_desc)
+                    const PangoFontDescription *base_desc)
 {
   GtkWidget *box;
   GtkWidget *sw;
@@ -776,7 +781,8 @@ benchmark_summary (void)
 int
 main (int argc, char **argv)
 {
-  GtkStyle *style;
+  GtkStyleContext *style;
+  const PangoFontDescription *font_desc;
   GtkWidget *window;
   GtkWidget *collection;
   GError *err;
@@ -853,28 +859,29 @@ main (int argc, char **argv)
                     G_CALLBACK (gtk_main_quit), NULL);
 
   gtk_widget_realize (window);
-  style = gtk_widget_get_style (window);
+  style = gtk_widget_get_style_context (window);
+  font_desc = gtk_style_context_get_font (style, 0);
 
   g_assert (style);
-  g_assert (style->font_desc);
+  g_assert (font_desc);
   
   notebook = gtk_notebook_new ();
   gtk_container_add (GTK_CONTAINER (window), notebook);
 
   collection = preview_collection (FONT_SIZE_NORMAL,
-                                   style->font_desc);
+                                   font_desc);
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
                             collection,
                             gtk_label_new (_("Normal Title Font")));
   
   collection = preview_collection (FONT_SIZE_SMALL,
-                                   style->font_desc);
+                                   font_desc);
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
                             collection,
                             gtk_label_new (_("Small Title Font")));
   
   collection = preview_collection (FONT_SIZE_LARGE,
-                                   style->font_desc);
+                                   font_desc);
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
                             collection,
                             gtk_label_new (_("Large Title Font")));
@@ -925,7 +932,12 @@ get_flags (GtkWidget *widget)
 static int
 get_text_height (GtkWidget *widget)
 {
-  return meta_pango_font_desc_get_text_height (gtk_widget_get_style (widget)->font_desc,
+  GtkStyleContext *style;
+  const PangoFontDescription *font_desc;
+
+  style = gtk_widget_get_style_context (widget);
+  font_desc = gtk_style_context_get_font (style, 0);
+  return meta_pango_font_desc_get_text_height (font_desc,
                                                gtk_widget_get_pango_context (widget));
 }
 
@@ -943,7 +955,7 @@ static void
 run_theme_benchmark (void)
 {
   GtkWidget* widget;
-  MetaPixmap *pixmap;
+  cairo_surface_t *pixmap;
   int top_height, bottom_height, left_width, right_width;
   MetaButtonState button_states[META_BUTTON_TYPE_LAST] =
   {
@@ -1007,11 +1019,12 @@ run_theme_benchmark (void)
       /* Creating the pixmap in the loop is right, since
        * GDK does the same with its double buffering.
        */
-      pixmap = meta_pixmap_new (gtk_widget_get_window (widget),
-                                client_width + left_width + right_width,
-                                client_height + top_height + bottom_height);
+      pixmap = gdk_window_create_similar_surface (gtk_widget_get_window (widget),
+                                                  CAIRO_CONTENT_COLOR,
+                                                  client_width + left_width + right_width,
+                                                  client_height + top_height + bottom_height);
 
-      cr = meta_pixmap_cairo_create (pixmap);
+      cr = cairo_create (pixmap);
 
       meta_theme_draw_frame (global_theme,
                              widget,
@@ -1027,7 +1040,7 @@ run_theme_benchmark (void)
                              meta_preview_get_icon ());
 
       cairo_destroy (cr);
-      meta_pixmap_free (pixmap);
+      cairo_surface_destroy (pixmap);
       
       ++i;
       client_width += inc;
